package com.ruoyi.bst.teamUser.mapper;

import java.util.List;
import com.ruoyi.bst.teamUser.domain.TeamUser;
import com.ruoyi.bst.teamUser.domain.TeamUserVO;
import com.ruoyi.bst.teamUser.domain.TeamUserQuery;
import org.apache.ibatis.annotations.Param;

/**
 * 拼桌用户Mapper接口
 *
 * @author ruoyi
 * @date 2025-05-22
 */
public interface TeamUserMapper
{
    /**
     * 查询拼桌用户
     *
     * @param id 拼桌用户主键
     * @return 拼桌用户
     */
    TeamUserVO selectTeamUserById(Long id);

    /**
     * 查询拼桌用户列表
     *
     * @param query 拼桌用户
     * @return 拼桌用户集合
     */
    List<TeamUserVO> selectTeamUserList(@Param("query")TeamUserQuery query);

    /**
     * 新增拼桌用户
     *
     * @param teamUser 拼桌用户
     * @return 结果
     */
    int insertTeamUser(TeamUser teamUser);

    /**
     * 批量新增拼桌用户
     */
    int batchInsert(@Param("list") List<? extends TeamUser> list);

    /**
     * 批量修改拼桌用户
     */
    int batchUpdate(@Param("list") List<? extends TeamUser> list);

    /**
     * 修改拼桌用户
     *
     * @param teamUser 拼桌用户
     * @return 结果
     */
    public int updateTeamUser(@Param("data") TeamUser teamUser);

    /**
     * 删除拼桌用户
     *
     * @param id 拼桌用户主键
     * @return 结果
     */
    int deleteTeamUserById(Long id);

    /**
     * 批量删除拼桌用户
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTeamUserByIds(Long[] ids);

    List<TeamUserVO> selectTeamUserListByTeamId(@Param("teamId") Long teamId);
}
